import requests
import settings
import json

GRAPHQL_API = settings.GraphQlApi
TENANT_ID = settings.TenantId
TENANT_KEY = settings.TenantKey
POINT_ID = settings.PointId

#------------------------------------------------------------------------------
#Method for Writing to the Dimensison4 GraphQL API-----------------------------
#------------------------------------------------------------------------------
def GraphQLWrite(sensorValue, timestamp):
    #GraphQL Server URL
    target = GRAPHQL_API
    
    # HTTP Header
    headers = {
        "x-tenant-id": TENANT_ID,
        "x-tenant-key": TENANT_KEY,
    }

    # Create GraphQL Query/Mutation
    query = """mutation CREATE_SIGNAL(
      $timestamp: Timestamp!
      $pointId: ID!
      $value: String!
      ){
      signal {
        create(input: {
          pointId: $pointId
          signals: [
            {
              unit: CELSIUS_DEGREES
              value: $value
              type: "Office Temperature"
              timestamp: $timestamp
            }
          ]
        }) {
          id
          timestamp
          createdAt
          pointId
          unit
          type
          data {
            numericValue
            rawValue
          }
        }
      }
    }"""

    jsonform = {
        "query": query,
        "variables": {
            "pointId": POINT_ID,
            "timestamp": timestamp,
            "value": sensorValue,
        },
    }
    
    #print(jsonform)
    
    print("Sending data...")
    try:
        res = requests.post(target, json=jsonform, headers=headers)
    except Exception as e:
        print(f"Error!: {e}")

    if res.status_code != 200:
        print("Send error!")
        print(res.text)

    else:
        res_json = res.json()
        if "errors" in res_json.keys():
            print("Query error!")
            print(res_json["errors"])
        else:
            print("Success!")
            print(res_json["data"])
#------------------------------------------------------------------------------            
            

#------------------------------------------------------------------------------
#Method for Reading from the Dimensison4 GraphQL API---------------------------
#------------------------------------------------------------------------------
def GraphQLRead(pointId):
    #GraphQL Server URL
    target = GRAPHQL_API
    
    # HTTP Header
    headers = {
        "x-tenant-id": TENANT_ID,
        "x-tenant-key": TENANT_KEY,
    }

    # Create GraphQL Query/Mutation
    query = """query LATEST_SIGNALS 
    (
      $pointId: String!
    )
    {
    signalsConnection(
    sort: {field: "timestamp", order:ASC}
    where: {pointId: {_EQ: $pointId}}
    paginate: {first:100}
    ){
    edges {
      node {
        id
        timestamp
        type
        unit
        data {
          numericValue
        }
      }
    }
    }
    }"""

    jsonform = {
        "query": query,
        "variables": {
            "pointId": pointId,
        },
    }
    
    #print(jsonform)
    
    print("Reading data...")
    try:
        res = requests.post(target, json=jsonform, headers=headers)
    except Exception as e:
        print(f"Error!: {e}")

    if res.status_code != 200:
        print("Send error!")
        print(res.text)

    else:
        res_json = res.json()
        if "errors" in res_json.keys():
            print("Query error!")
            print(res_json["errors"])
        else:
            print("Success!")
            # Parse JSON Data
            data = str(res_json["data"])
            data = data.replace("'", '"')
            jsondata = json.loads(data)
            jsonString = json.dumps(jsondata, indent=1)

            # Find Number of Values
            N = len(jsondata["signalsConnection"]["edges"]) 
            print(N)
            
            # Get Value and TimeStamp from JSON String
            signalData = []
            signalTimeStamp = []
            for x in range(N):
                fieldValue = float(jsondata["signalsConnection"]["edges"][x]["node"]["data"]["numericValue"])
                signalData.append(fieldValue)
                
                fieldTimeStamp = jsondata["signalsConnection"]["edges"][x]["node"]["timestamp"]
                signalTimeStamp.append(fieldTimeStamp)  

            return jsonString, signalData, signalTimeStamp
#------------------------------------------------------------------------------